@@ -17,7 +17,7 @@ from .help_layout import HelpLayout, HelpState, random_error_quote
 from .overview_layout import OverviewLayout, OverviewState, PreviewState
 from .stack_layout import StackFrame, StackLayout
 
-version = "1.2.5"
+version = "1.2.6"
 
 # TODO fix explore(namedtuple)
 # TODO methods filter
@@ -54,7 +54,11 @@ class Explorer:
         )
 
         # Run self.draw() whenever the win change signal is caught
-        signal.signal(signal.SIGWINCH, self.draw)
+        try:
+            signal.signal(signal.SIGWINCH, self.draw)
+        except AttributeError:
+            # OS does not have SIGWINCH signal
+            pass
 
     def explore(self) -> Optional[Any]:
         """ Open the interactive explorer """
@@ -255,13 +259,19 @@ class Explorer:
 
         elif key == "i":
             with console.capture() as capture:
-                rich.inspect(self.cached_obj.selected_cached_obj.obj, console=console, methods=True)
+                rich.inspect(
+                    self.cached_obj.selected_cached_obj.obj,
+                    console=console,
+                    methods=True,
+                )
             str_out = capture.get()
             pydoc.pager(str_out)
 
         elif key == "I":
             with console.capture() as capture:
-                rich.inspect(self.cached_obj.selected_cached_obj.obj, console=console, all=True)
+                rich.inspect(
+                    self.cached_obj.selected_cached_obj.obj, console=console, all=True
+                )
             str_out = capture.get()
             pydoc.pager(str_out)
 
